/**
 * Base class for typed errors, adding nested errors (causes) to the stack.
 *
 * @public
 */
export declare class BaseError extends Error {
    readonly message: string;
    readonly stack?: string;
    protected nested: Array<Error>;
    /**
     * Create a new typed error.
     *
     * @param message - error message
     * @param nested - internal errors (causes)
     */
    constructor(message: string, ...nested: Array<Error>);
    /**
     * Get the cause of this error: the first nested error.
     *
     * @public
     */
    get cause(): Error | undefined;
    /**
     * Get the number of nested errors.
     *
     * @public
     */
    get length(): number;
}
//# sourceMappingURL=BaseError.d.ts.map