/**
 * Available log levels.
 *
 * @public
 */
export declare enum LogLevel {
    Debug = "debug",
    Error = "error",
    Info = "info",
    Warn = "warn",
    DEBUG = "debug",
    ERROR = "error",
    INFO = "info",
    WARN = "warn"
}
export declare type LogParams = object;
/**
 * Log interface to fit console or bunyan.
 *
 * @public
 */
export interface Logger {
    child(options: any): Logger;
    debug(msg: string, ...params: Array<unknown>): void;
    debug(options: LogParams, msg: string, ...params: Array<unknown>): void;
    error(msg: string, ...params: Array<unknown>): void;
    error(err: Error, msg: string, ...params: Array<unknown>): void;
    error(options: LogParams, msg: string, ...params: Array<unknown>): void;
    info(msg: string, ...params: Array<unknown>): void;
    info(options: LogParams, msg: string, ...params: Array<unknown>): void;
    warn(msg: string, ...params: Array<unknown>): void;
    warn(options: LogParams, msg: string, ...params: Array<unknown>): void;
}
/**
 * Switch helper to invoke log methods based on variable log level. Dispatches a call to the appropriate log level
 * method.
 *
 * @public
 */
export declare function logWithLevel(logger: Logger, level: LogLevel, options: Error | LogParams, msg: string): void;
//# sourceMappingURL=Logger.d.ts.map