import { isConstructor } from '../Container.js';
import { Module } from '../Module.js';
/**
 * Reference module that provides dependencies from a map-like of instances or constructors.
 *
 * To add providers to this module, extend it with `@Provides` methods.
 *
 * @public
 */
export class MapModule extends Module {
    constructor(options) {
        super();
        if (options.providers instanceof Map) {
            this.providerMap = new Map(options.providers);
        }
        else {
            this.providerMap = new Map(Object.entries(options.providers));
        }
    }
    async configure(options) {
        await super.configure(options);
        for (const [contract, value] of this.providerMap) {
            if (this.logger !== undefined) {
                this.logger.debug({ contract, value }, 'binding mapped provider');
            }
            if (isConstructor(value)) {
                this.bind(contract).toConstructor(value);
            }
            else {
                this.bind(contract).toInstance(value);
            }
        }
    }
}
//# sourceMappingURL=MapModule.js.map