import { DescriptorNotFoundError } from '../error/DescriptorNotFoundError.js';
import { MissingValueError } from '../error/MissingValueError.js';
/* eslint-disable-next-line @typescript-eslint/ban-types */
export function isNil(val) {
    /* eslint-disable-next-line no-null/no-null */
    return val === null || val === undefined;
}
export function doesExist(val) {
    return !isNil(val);
}
export function mustExist(val) {
    if (isNil(val)) {
        throw new MissingValueError('value must exist');
    }
    return val;
}
/* eslint-disable-next-line @typescript-eslint/no-explicit-any */
export function resolveDescriptor(target, key, providedDescriptor) {
    if (doesExist(providedDescriptor)) {
        return providedDescriptor;
    }
    const desc = Reflect.getOwnPropertyDescriptor(target, key);
    if (doesExist(desc)) {
        return desc;
    }
    const proto = Reflect.getPrototypeOf(target);
    if (doesExist(proto)) {
        return resolveDescriptor(proto, key);
    }
    throw new DescriptorNotFoundError();
}
//# sourceMappingURL=index.js.map