import { __decorate } from "tslib";
import { expect } from 'chai';
import { constructWithContainer, Container, invokeWithContainer } from '../../src/Container.js';
const TEST_STRING = 'test';
describe('container decorators', async () => {
    describe('construct with', async () => {
        it('should attach a container', async () => {
            const ctr = Container.from();
            await ctr.configure();
            let TestClass = class TestClass {
                constructor(options) {
                    this.container = options.container;
                }
            };
            TestClass = __decorate([
                constructWithContainer(ctr)
            ], TestClass);
            const instance = new TestClass({});
            expect(instance.container).to.equal(ctr);
        });
        it('should pass on any other options', async () => {
            const ctr = Container.from();
            await ctr.configure();
            let TestClass = class TestClass {
                constructor(options) {
                    this.container = options.container;
                    this.other = options.other;
                }
            };
            TestClass = __decorate([
                constructWithContainer(ctr)
            ], TestClass);
            const instance = new TestClass({
                other: TEST_STRING,
            });
            expect(instance.other).to.equal(TEST_STRING);
        });
        it('should pass on any other arguments', async () => {
            const ctr = Container.from();
            await ctr.configure();
            let TestClass = class TestClass {
                constructor(options, param1, param2) {
                    this.container = options.container;
                    this.param1 = param1;
                    this.param2 = param2;
                }
            };
            TestClass = __decorate([
                constructWithContainer(ctr)
            ], TestClass);
            const arg1 = {};
            const arg2 = {};
            const instance = new TestClass({}, arg1, arg2);
            expect(instance.param1).to.equal(arg1);
            expect(instance.param2).to.equal(arg2);
        });
    });
    describe('invoke with', async () => {
        it('should attach a container', async () => {
            const ctr = Container.from();
            await ctr.configure();
            const fn = invokeWithContainer(ctr, (options) => {
                return options.container;
            });
            expect(fn({})).to.equal(ctr);
        });
        it('should pass on any other options', async () => {
            const ctr = Container.from();
            await ctr.configure();
            const fn = invokeWithContainer(ctr, (options) => {
                return options.other;
            });
            expect(fn({
                other: TEST_STRING,
            })).to.equal(TEST_STRING);
        });
        it('should pass on any other arguments', async () => {
            const ctr = Container.from();
            await ctr.configure();
            const fn = invokeWithContainer(ctr, (options, param1, param2) => {
                return [param1, param2];
            });
            const arg1 = {};
            const arg2 = {};
            expect(fn({}, arg1, arg2)).to.deep.equal([arg1, arg2]);
        });
    });
});
//# sourceMappingURL=TestDecorator.js.map