import { BaseOptions, Container } from '../../src/index.js';
export declare type CacheFallback = (path: string) => Promise<string>;
/**
 * Base class for a cache.
 *
 * Both of these base classes could be abstract or interfaces, but
 * interfaces are types rather than values, and neither can be used
 * in calls to bind or inject.
 */
export declare class Cache {
    get(path: string, ttl: number, fallback: CacheFallback): Promise<string>;
}
export declare class Filesystem {
    get(path: string): Promise<string>;
}
export interface ServerOptions extends BaseOptions {
    cache: Cache;
    filesystem: Filesystem;
    ttl: number;
}
export declare class Server implements ServerOptions {
    readonly cache: Cache;
    readonly container: Container;
    readonly filesystem: Filesystem;
    readonly ttl: number;
    /**
     * Having the class implement the same options used by the constructor
     * provides a free copy constructor.
     */
    constructor(options: ServerOptions);
    get(path: string): Promise<string>;
}
//# sourceMappingURL=index.d.ts.map