import { __decorate } from "tslib";
import { Inject } from '../../src/index.js';
/**
 * Base class for a cache.
 *
 * Both of these base classes could be abstract or interfaces, but
 * interfaces are types rather than values, and neither can be used
 * in calls to bind or inject.
 */
export class Cache {
    /* c8 ignore next 3 */
    get(path, ttl, fallback) {
        throw new Error('not implemented');
    }
}
export class Filesystem {
    /* c8 ignore next 3 */
    get(path) {
        throw new Error('not implemented');
    }
}
let Server = class Server {
    /**
     * Having the class implement the same options used by the constructor
     * provides a free copy constructor.
     */
    constructor(options) {
        this.cache = options.cache;
        this.container = options.container;
        this.filesystem = options.filesystem;
        this.ttl = options.ttl;
    }
    get(path) {
        return this.cache.get(path, this.ttl, () => this.filesystem.get(path));
    }
};
Server = __decorate([
    Inject(Cache.name.toLowerCase(), Filesystem.name.toLowerCase())
], Server);
export { Server };
//# sourceMappingURL=index.js.map